#######################################################
# wsadmin script to deploy Emptoris Contract Management
#######################################################

########### Start Imports ###########
from install.GetProfilePath import GetProfilePath
from install.WASService import WASService

from util.Boolean import * 
import util.utility as util

import was_objs.import_was as wasScript
execfile(wasScript.__file__)
########### End Imports ###########

########### Start Variable Definitions ###########
wasHome = args['wasHome']
profileName = args['profileName']
serverName = args['serverName']
nodeName = args['nodeName']
cellName = args['cellName']
suiteApps = None


########### End Variable Definitions ###########

# Make sure the WAS profile exists
profilePath = GetProfilePath(wasHome).getProfilePath(profileName)
if profilePath is None:
    raise Exception('Could not find target profile path for profile [' + profileName + ']') 

try:
    print "Configuring IBM Emptoris Strategic Supply Management..."

    ########### Create a new server ###########
    svr = server.Server(serverName, nodeName, cellName)
    svr.setPortSet(args['portSet'])
    svr.configure()
    
    
    oracleDatabase = "Oracle"
    db2Database = "DB2"
    if args['rdbmsVendor'] == oracleDatabase :
        varName = "ORACLE_JDBC_DRIVER_PATH"
    else:
        varName = "DB2_JCC_DRIVER_PATH"
    newVarValue = args['jdbcDriverPath']
    nodeConfigId = AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName + '/')
    varSubstitutions = AdminConfig.list("VariableSubstitutionEntry",nodeConfigId).splitlines()
    for varSubst in varSubstitutions:
        getVarName = AdminConfig.showAttribute(varSubst, "symbolicName")
        if getVarName == varName:
            AdminConfig.modify(varSubst,[["value", newVarValue]])
            break
    print 'database = ' + oracleDatabase
    print  'url = '+ args['dataSourceUrl']
    
    ########### Start JVM Configuration ###########
    jvmconfig = jvm.JavaVirtualMachine(svr)
    jvmconfig.setInitialHeapSize(args['javaHeap'])
    jvmconfig.setMaximumHeapSize(args['javaHeap'])
    jvmconfig.setClasspath([args['gatewayClasspath']])
    jvmconfig.addJvmArg('-Dfile.encoding=UTF8')
    jvmconfig.addJvmArg('-Drivermine.registries=com.rivermine.app.gateway.GatewayRegistry')
    jvmconfig.addJvmArg('-Drivermine.mode=prod')
    jvmconfig.addJvmArg('-Drivermine.server.port='+ str(args['rivermineServerPort']))
    jvmconfig.addJvmArg('-Drivermine.home='+ args['rivermineHome'])
    jvmconfig.addJvmArg('-Ddefault.language='+ args['defaultLanguage'])
  
    suiteApps = []
    if args['pgm.enabled'] == 'true':
        suiteApps.append('PGM')
        
    if args['suite.apps.slm'] == 'SLM':
        suiteApps.append('SLM')
        jvmconfig.addJvmArg('-Dslm.web.url='+ args['slm.web.protocol']+ '://'+ args['slm.web.host']+ ':'+ str(args['slm.web.port'])+ '/srm-app')
        
    if args['suite.apps.esp'] == 'ESP':
        suiteApps.append('ESP')
        jvmconfig.addJvmArg('-Desp.web.url='+ args['esp.web.protocol']+ '://'+ args['esp.web.host']+ ':'+ str(args['esp.web.port']))
        
    if args['suite.apps.ecm'] == 'ECM':
        suiteApps.append('ECM')
        jvmconfig.addJvmArg('-Decm.web.url='+ args['ecm.web.protocol']+ '://'+ args['ecm.web.host']+ ':'+ str(args['ecm.web.port'])+ '/dicarta')
        
    if args['suite.apps.spend'] == 'Spend':
        suiteApps.append('Spend')
        jvmconfig.addJvmArg('-Dspend.web.url='+ args['spend.web.protocol']+ '://'+ args['spend.web.host']+ ':'+ str(args['spend.web.port'])+ '/expensemap')
        
    if suiteApps is not None and len(suiteApps) > 0:
        jvmconfig.addJvmArg('-Dsuite.apps='+ ','.join(suiteApps))
    jvmconfig.configure()
    ########### End JVM Configuration ###########
    
    ########### Start DataSource Configuration ###########
    auth = jaasAuthData.JAASAuthData()
    auth.setAlias(args['dataSourceName'])
    auth.setDescription("Credentials for DefaultDS")
    auth.setUserId(args['dataSourceUserId'])
    auth.setPassword(args['dataSourcePassword'])
    auth.setServer(svr)
    auth.configure()
        
    jdbcP = jdbcProvider.JDBCProvider()
    jdbcP.setName(args['dataSourceName'])
    jdbcP.setVendor(args['rdbmsVendor'])
    jdbcP.setClasspath(args['jdbcDriverLocation'])
    jdbcP.setServer(svr)
    jdbcP.configure()

    ds = dataSource.DataSource()
    ds.setName(args['dataSourceName'])
    ds.setCategory(args['dataSourceName'])
    ds.setJndiName(args['dataSourceJndiName'])
    if 'dataSourceUrl' in args.keys() and args['rdbmsVendor'] == oracleDatabase :
        ds.setURL(args['dataSourceUrl'])
    else:
        ds.setResourceAttribute('databaseName', args['databaseServicename'])
        ds.setResourceAttribute('driverType', 4, 'java.lang.Integer')
        ds.setResourceAttribute('serverName', args['databaseIP'])
        ds.setResourceAttribute('portNumber', args['databasePort'], 'java.lang.Integer')
    ds.setAuthDataAlias(auth)
    ds.setServer(svr)
    ds.setJdbcProvider(jdbcP)
    ds.configure()
    datasourceConfigId = ds.getConfigId()
    connectionPoolId = AdminConfig.list('ConnectionPool', datasourceConfigId)
    AdminConfig.modify(connectionPoolId, '[[maxConnections "25"] [minConnections "5"]]')
    if args['rdbmsVendor'] == db2Database :
        ds.setResourceAttribute('currentSchema', args['db2Schema'])
        ds.setResourceAttribute('currentFunctionPath', args['db2Schema'])
        ds.configure()
    
    ########### End DataSource Configuration ###########
    
    ########### Start Library Configuration ###########
    sharedLib = library.Library("Library")
    sharedLib.setDescription('Shared library for Gateway')
    sharedLib.setScope(svr.getCellContainmentPathId())
    sharedLib.setClassPath(args['appLibLocation'])
    sharedLib.configure()
    ########### End Library Configuration ###########

    ########### Start login entry ###########
    gatewayLoginEntry = jaasLoginEntry.JAASLoginEntry()
    gatewayLoginEntry.setLoginEntryAlias('Gateway')
    gatewayLoginEntry.setLoginType('application')

    
    
    
    
    # SSOClientLoginModule
    #ssoLoginModule = jaasAppLoginModule.JAASApplicationLoginModule()
    #ssoLoginModule.setLoginEntryAlias('Sso')
    #ssoLoginModule.setLoginModule('com.emptoris.framework.remote.client.sso.SSOClientLoginModule')
    #ssoLoginModule.setAuthStrategy('REQUIRED')
    #ssoLoginModule.addCustomProperty('debug','false')
    
    

     

    ########### Start Application Deployment ###########
    domainName = ""
    if 'domainName' in args.keys() and args['domainName'] is not None:
        domainName = args['domainName']
    
    inst = installer.Installer(args['appWarLocation'], args['installerPropertiesLocation'])
    inst.setServer(svr)
    
    ctxRoot = '/emptoris'
    inst.setCtxRootForWebMod([[".*", ".*", ctxRoot]])      
    inst.setContextroot(ctxRoot)
    inst.setMapSharedLibForMod([[".*", 'META-INF/application.xml', sharedLib.getName()]])
    inst.setMapResRefToEJB([[".*", "", 'emptoris.war,WEB-INF/web.xml', 'jdbc/RivermineDB', 'javax.sql.DataSource', ds.getJndiName(), "", "", "", ]])
    inst.setProcessEmbeddedConfig(false)
    inst.setNoprocessEmbeddedConfig(true)
    inst.setCookieDomain(domainName)
    inst.configure()
    print "Saving changes..."
    AdminConfig.save()
    print "Changes saved."
    ########### End Application Deployment ###########
except Exception, e:
    print "Server configuration failed.  Rolling back changes."
    AdminConfig.reset()
    raise # Re-throw to terminate the script
    
    
